@@ -4,8 +4,8 @@
 import h5py
 from rest_framework import serializers
 
-from db.base.models import TRANSMITTER_STATUS, Artifact, DemodData, \
-    LatestTleSet, Mode, Satellite, Telemetry, Transmitter
+from db.base.models import TRANSMITTER_STATUS, Artifact, DemodData, LatestTleSet, Mode, \
+    Satellite, Telemetry, Transmitter
 
 
 class ModeSerializer(serializers.ModelSerializer):
@@ -179,7 +179,10 @@ class SidsSerializer(serializers.ModelSerializer):
     """SatNOGS DB SiDS API Serializer"""
     class Meta:
         model = DemodData
-        fields = ('satellite', 'payload_frame', 'station', 'lat', 'lng', 'timestamp', 'app_source')
+        fields = (
+            'satellite', 'payload_frame', 'station', 'lat', 'lng', 'timestamp', 'app_source',
+            'observer'
+        )
 
 
 class ArtifactSerializer(serializers.ModelSerializer):
