@@ -1,7 +1,4 @@
 """SatNOGS DB django management command to initialize a new database"""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 from django.core.management import call_command
 from django.core.management.base import BaseCommand
 
